{ pkgs ? import <nixpkgs> {} }:

let
  pySmartDL = pkgs.callPackage ./development/python/pySmartDL {};
  cfscrape = pkgs.callPackage ./development/python/cfscrape {};
  system_hotkey = pkgs.callPackage ./development/python/system_hotkey {};
  buildFHSUserEnvBubblewrap = pkgs.callPackage ./build-support/build-fhs-userenv-bubblewrap {};
  discord-system-electron = pkgs.callPackage ./applications/networking/instant-messengers/discord {
    # Wayland
    # NOTE: electron under Wayland has no window titlebars
    #extraStartupArgs = "--enable-features=UseOzonePlatform --ozone-platform=wayland";
  };
  discord-system-electron-wrapped = pkgs.callPackage ./applications/networking/instant-messengers/discord/wrapped.nix {
    buildFHSUserEnvBubblewrap = buildFHSUserEnvBubblewrap;
    discord = discord-system-electron;
  };
in { 
  gamemode = pkgs.callPackage ./tools/games/gamemode { };
  key-mapper = pkgs.callPackage ./tools/games/key-mapper {};
  vfio-isolate = pkgs.callPackage ./tools/virtualisation/vfio-isolate {};
  mopidy-funkwhale = pkgs.callPackage ./applications/audio/mopidy/funkwhale.nix {};
  # Not as clean as I hoped, but it works
  gnomeExtensions = pkgs.gnomeExtensions // {
    notification-timeout = pkgs.callPackage ./desktop/gnome/extensions/notification-timeout {};
    windowisready-remover = pkgs.callPackage ./desktop/gnome/extensions/windowisready-remover {};
  };
  python3Packages = pkgs.python3Packages // {
    pySmartDL = pySmartDL;
    cfscrape = cfscrape;
    system_hotkey = system_hotkey;
  };
  replaysorcery = pkgs.callPackage ./tools/games/replaysorcery {};
  evdev-proxy = pkgs.callPackage ./tools/virtualisation/evdev-proxy {};
  anime4k = pkgs.callPackage ./misc/video/anime4k {};
  anime-dl = pkgs.callPackage ./tools/video/animedl {
    pySmartDL = pySmartDL;
    cfscrape = cfscrape;
  };
  superpaper = pkgs.callPackage ./applications/desktop/superpaper {
    system_hotkey = system_hotkey;
  };
  discord-system-electron = discord-system-electron;
  discord-system-electron-wrapped = discord-system-electron-wrapped;
  discord-wrapper = pkgs.callPackage ./applications/networking/instant-messengers/discord/desktop.nix {
    discord = discord-system-electron-wrapped;
  };
}
